summaryrefslogtreecommitdiff
path: root/jstests/replsets/tenant_migration_cluster_time_keys_cloning.js
diff options
context:
space:
mode:
authorJack Mulrow <jack.mulrow@mongodb.com>2021-02-08 15:42:26 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-02-27 00:03:44 +0000
commitf676daac201f886a3994c545f9bb8636e7ed15a0 (patch)
treef93f37e04f6c58a869e1dfb08138beb5ea65b37a /jstests/replsets/tenant_migration_cluster_time_keys_cloning.js
parent811837f75614e7f24457c7e1bb80bff6e688d57f (diff)
downloadmongo-f676daac201f886a3994c545f9bb8636e7ed15a0.tar.gz
SERVER-53406 Add TTL for external keys
Diffstat (limited to 'jstests/replsets/tenant_migration_cluster_time_keys_cloning.js')
-rw-r--r--jstests/replsets/tenant_migration_cluster_time_keys_cloning.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/jstests/replsets/tenant_migration_cluster_time_keys_cloning.js b/jstests/replsets/tenant_migration_cluster_time_keys_cloning.js
index d2bba452dc1..d3dcd47cf2b 100644
--- a/jstests/replsets/tenant_migration_cluster_time_keys_cloning.js
+++ b/jstests/replsets/tenant_migration_cluster_time_keys_cloning.js
@@ -1,6 +1,6 @@
/**
* Test that tenant migration donor and recipient correctly copy each other cluster time keys into
* their admin.system.external_validation_keys collection.
*
* @tags: [requires_fcv_47, requires_majority_read_concern, incompatible_with_eft,
* incompatible_with_windows_tls]
@@ -14,11 +14,11 @@ load("jstests/libs/uuid_util.js");
load("jstests/replsets/libs/tenant_migration_test.js");
const kInternalKeysNs = "admin.system.keys";
-const kExternalKeysNs = "admin.system.external_validation_keys";
+const kExternalKeysNs = "config.external_validation_keys";
/**
* Asserts that the donor and recipient have copied each other's cluster time keys into
- * admin.system.external_validation_keys.
+ * config.external_validation_keys.
*/
function assertCopiedExternalKeys(tenantMigrationTest, migrationId) {
const donorPrimary = tenantMigrationTest.getDonorPrimary();
@@ -1,6 +1,6 @@
/**
* Test that tenant migration donor and recipient correctly copy each other cluster time keys into
- * their admin.system.external_validation_keys collection.
+ * their config.external_validation_keys collection.
*
* @tags: [requires_fcv_47, requires_majority_read_concern, incompatible_with_eft,